#
# spec file for package edict
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           edict
Version:        20230511
Release:        1.1
Summary:        The Japanese Dictionary from the EDRDG project (EDICT format)
License:        CC-BY-SA-3.0 AND CC-BY-SA-4.0
Group:          System/I18n/Japanese
URL:            http://www.edrdg.org/jmdict/edict.html
# The files change daily, so we do not include their full URL here,
# but do see download_dicts.sh.
Source:         JMdict.gz
Source2:        edict.gz
Source3:        edict2u.gz
Source4:        enamdict.gz
Source6:        kanjidic2.xml.gz
Source7:        kanjidic.gz
Source8:        kanjd212.gz
Source9:        kradfile.gz
Source10:       radkfile.gz
Source11:       kanjd213u.gz
Source97:       download_dicts.sh
Source98:       http://www.edrdg.org/edrdg/licence.html
Source99:       http://www.kanji.org/kanji/dictionaries/skip_permission.htm
BuildArch:      noarch

%description
JMdict/EDICT is a machine-readable multilingual Japanese dictionary.
It contains Japanese–English translations for over 180000 entries,
representing more than 205000 unique headword–reading combinations.

The dictionary is made available in different formats. This package
contains the "edict"/UTF8 variant, a flat text file format, of:

* the JMdict project's word dictionary ("edict" file)
* the KANJIDIC project's JIS X 0208-1990 Kanji dictionary (6355 Kanji)
* KANJIDIC's JIS X 0212-1990 dictionary (an extra 5801 Kanji)
* KANJIDIC's JIS X 0213-2012 dictionary (an extra 952 Kanji)
* kanji-to-radical and radical-to-kanji indices
* ENAMDICT, a dictionary for proper names

Other formats are in the edict2 and jmdict packages.

%package eucjp
Summary:        The Japanese Dictionary from the EDRDG project (EDICT-EUCJP format)
Group:          System/I18n/Japanese
Provides:       locale(ja)

%description eucjp
JMdict/EDICT is a machine-readable multilingual Japanese dictionary.
It contains Japanese–English translations for over 180000 entries,
representing more than 205000 unique headword–reading combinations.

The dictionary is made available in different formats. This package
contains the "edict"/EUC-JP variant.

%package -n edict2
Summary:        The Japanese Dictionary from the EDRDG project (edict2 format)
Group:          System/I18n/Japanese
Provides:       locale(ja)

%description -n edict2
JMdict/EDICT is a machine-readable multilingual Japanese dictionary.
It contains Japanese–English translations for over 180000 entries,
representing more than 205000 unique headword–reading combinations.

The dictionary is made available in different formats. This package
contains the "edict2" variant, an expanded version of the flat
"edict" text format but reflecting the structure of the XML entries,
of the JMdict word dictionary.

%package -n jmdict
Summary:        The Japanese Dictionary from the EDRDG project (JMdict format)
Group:          System/I18n/Japanese
Provides:       locale(ja)

%description -n jmdict
JMdict/EDICT is a machine-readable multilingual Japanese dictionary.
It contains Japanese–English translations for over 180000 entries,
representing more than 205000 unique headword–reading combinations.

The dictionary is made available in different formats. This package
contains the XML variant of:

* the JMdict project's word dictionary ("JMdict" file)
* the KANJIDIC project's Kanji dictionary (covering JIS 0208/0212/0213;
  "kanjidic2.xml" file)

%prep
# Make %%doc work
cp "%_sourcedir"/*.htm* .

%build

%install
# Other packages look for files predominantly here, and expect files to be UTF-8.
d="%buildroot/%_datadir/edict"
mkdir -p "$d"
pushd "%_sourcedir/"
# files already in the right encoding
for i in JMdict.gz edict2u.gz kanjd213u.gz kanjidic2.xml.gz; do
	gzip -cd "$i" >"$d/${i%.gz}"
done
# transcode some files
for i in edict.gz enamdict.gz kanjd212.gz kanjidic.gz kradfile.gz radkfile.gz; do
	gzip -cd "$i" >"$d/${i%.gz}.eucjp"
	iconv -f euc-jp -t utf-8 <"$d/${i%.gz}.eucjp" >"$d/${i%.gz}"
done
popd

%files
%license licence.html skip_permission.htm
%dir %_datadir/edict/
%_datadir/edict/edict
%_datadir/edict/enamdict
%_datadir/edict/kanjd212
%_datadir/edict/kanjd213u
%_datadir/edict/kanjidic
%_datadir/edict/kradfile
%_datadir/edict/radkfile

%files eucjp
%license licence.html skip_permission.htm
%dir %_datadir/edict/
%_datadir/edict/edict.eucjp
%exclude %_datadir/edict/enamdict.eucjp
%exclude %_datadir/edict/kanjd212.eucjp
%_datadir/edict/kanjidic.eucjp
%exclude %_datadir/edict/kradfile.eucjp
%_datadir/edict/radkfile.eucjp

%files -n jmdict
%license licence.html
%dir %_datadir/edict/
%_datadir/edict/JMdict
%_datadir/edict/kanjidic2.xml

%files -n edict2
%license licence.html
%dir %_datadir/edict/
%_datadir/edict/edict2u

%changelog
* Thu May 11 2023 Jan Engelhardt <jengelh@inai.de>
- Update to snapshot 20230511
  * No changelog recorded.
- Provide EUC-JP encoded variants again, for the "kiten" program.
* Mon Apr 10 2023 Jan Engelhardt <jengelh@inai.de>
- Update to snapshot 20230411
  * No changelog recorded.
* Sat Apr  2 2022 Jan Engelhardt <jengelh@inai.de>
- Update to snapshot 20220402
  * No changelog recorded.
* Sun Feb 13 2022 Jan Engelhardt <jengelh@inai.de>
- Update to snapshot 20220214
  * No changelog recorded.
* Fri Dec 31 2021 Jan Engelhardt <jengelh@inai.de>
- Update to snapshot 20211231
  * No changelog recorded.
* Sat May 29 2021 Jan Engelhardt <jengelh@inai.de>
- Update to snapshot 20210529
  * Approximately 600 entries were updated.
* Thu Apr 29 2021 Jan Engelhardt <jengelh@inai.de>
- Update to snapshot 20210429
  * No changelog recorded.
* Sun Nov  1 2020 Jan Engelhardt <jengelh@inai.de>
- Update to snapshot 20201102
  * No changelog recorded.
* Tue Aug 25 2020 Jan Engelhardt <jengelh@inai.de>
- Update to snapshot 20200825
  * No changelog recorded.
* Thu Feb 13 2020 Stanislav Brabec <sbrabec@suse.com>
- Fix invalid RPM group.
* Fri Jan  3 2020 Fuminobu Takeyama <ftake@geeko.jp>
- Drop "Provides: locale(ja)" to reduce the size of Japanese base
  system
* Thu Oct 17 2019 Jan Engelhardt <jengelh@inai.de>
- Update to snapshot 20191016
  * No changelog recorded.
* Thu Mar 14 2019 Jan Engelhardt <jengelh@inai.de>
- Update to snapshot 20190313
  * No changelog recorded.
* Mon Nov 26 2018 Jan Engelhardt <jengelh@inai.de>
- Update to snapshot 20181125
  * No changelog recorded.
- Split package into: edict, edict2, jmdict. This way, one need not
  install the rather large XML variant (jmdict) if not needed.
- Added JIS X 0213-2012 Kanji dictionary ("kanjd213").
- Remove the computer terminology dictionary "compdic", as it is
  already included in the word dictionary.
* Mon Mar  5 2018 jengelh@inai.de
- Update to snapshot 20180305
  * No changelog recorded. About 6000 new dictionary entries.
* Thu Jul  6 2017 jengelh@inai.de
- Update to new daily snapshot release 20170706
  * More than 1500 new entries to edict; no specific changelog
    known
* Sat Nov 26 2016 jengelh@inai.de
- Update to new daily snapshot release 20161126
  * 10 dictionary files are now under CC-BY-SA,
  the rest with other licenses has been removed from this package.
* Sun Sep 18 2011 jengelh@medozas.de
- Remove redundant/obsolete tags/sections from specfile
  (cf. packaging guidelines)
* Mon Aug  7 2006 mfabian@suse.de
- update to latest versions. Updated dictionaries are
  edict, enamdict, kanjdic, kanjd212, and compdic.
* Wed Mar  1 2006 mfabian@suse.de
- add "Provides: locale(ja)".
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Wed Feb  9 2005 mfabian@suse.de
- updated edict to EDICT 10DEC04 V04-003
- updated enamdict to ENAMDICT 05JAN05 V2005-01
- remove jddict, it has a problematic license.
* Wed Dec  8 2004 mfabian@suse.de
- update license files contained in the package documentation
  to the latest versions and reword "Copyright" file according to
  Jim Breen's "Sample Acknowledgement"
  http://www.csse.monash.edu.au/groups/edrdg/sample.html
- updated edict to EDICT 14AUG04 V04-002.
- updated kanjidic to 14AUG2004.
* Tue Aug 10 2004 mfabian@suse.de
- updated edict to EDICT 07JUN04 V04-001
- updated enamdict to ENAMDICT 13APR04 V2004-01
- updated kanjidic to 11MAR2004
- add COPYRIGHT-KANJIDIC-JACK-HALPERN file.
* Tue Feb 24 2004 hmacht@suse.de
- building as non-root
* Mon Aug 25 2003 mfabian@suse.de
- updated all dictionaries to their latest version:
  - edict updated to EDICT 19AUG03 V03-004
  - enamdict updated to ENAMDICT 19AUG03 V2003-02
  - kanjidic updated to 21JUL2003
- use UTF-8 versions of dictionaries when available,
  convert all others to UTF-8 with iconv.
* Fri Jun 13 2003 mfabian@suse.de
- add %%dir /usr/share/edict/ to file list.
* Fri May 16 2003 mfabian@suse.de
- don't install files which are not packaged.
* Sun Feb 16 2003 mfabian@suse.de
- updated all dictionaries to their latest version:
  - edict updated to EDICT 04FEB03 V03-001
  - enamdict updated to ENAMDICT 06DEC02 V2002-03
  - compdic updated to COMPDIC 24OCT02 V02-001
- added buddhdic (Buddhistic terms)
* Sat Aug 10 2002 mfabian@suse.de
- updated all dictionaries to their latest version:
  - edict updated to EDICT 25APR02 V02-001
  - enamdict updated to ENAMDICT 11JUL02 V2002-02
* Mon Mar 18 2002 mfabian@suse.de
- updated all dictionaries to their latest version:
  - compdic updated to COMPDIC 04DEC01 V01-002
  - edict updated to EDICT 28NOV01 V01-002
  - enamdict updated to ENAMDICT 22JUN01 V2001-01
  - kanjidic updated to 06FEB2002
  - aviation updated
- added a few dictionaries
  - ediclsd3 (EDICLSD3 24JAN97/Life Sciences Dictionary File)
  - engscidic (engineering and physical sciences)
  - lawgledt (University of Washington Japanese-English
    Legal Glossary)
  - stardict (26JAN01 V01-001/Dictionary of Constellations)
* Mon Oct 30 2000 mfabian@suse.de
- added rpm group tag
* Mon Sep 11 2000 mfabian@suse.de
- remove %%{?suse_update_config}, it is not needed and makes the
  build fail on 6.4K-i386
* Fri Sep  8 2000 mfabian@suse.de
- new package edict-20000827
